@@ -14,32 +14,20 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
-//$Id: radioactive.h,v 1.24 2001/11/06 17:45:38 cactus Exp $ -*- c++ -*-
-#ifndef RADIO_h
-#define RADIO_h
+//$Id: radioactive.h,v 1.27 2002/01/25 17:32:22 cactus Exp $ -*- c++ -*-
+#ifndef RADIOACTIVE_H
+#define RADIOACTIVE_H
 
-#include "config.h"
+#define RADIOACTIVE_RCDIR ".radioactive"
+#define RADIOACTIVE_DEVFILE "/dev/radio0"
 
-#define PROGNAME "RadioActive"
-#define RADIO_RCDIR ".radioactive"
-#define DEVFILE "/dev/radio0"
+#define RADIOACTIVE_VOL_MIN 0
+#define RADIOACTIVE_VOL_MAX 10
+#define RADIOACTIVE_VOL_DEF 8
 
-#define RADIO_VOL_MIN 0
-#define RADIO_VOL_MAX 10
-#define RADIO_VOL_DEF 8
+#define RADIOACTIVE_APPLET_TIMEOUT      1000 // Timeout for holding down the
+                                             // mouse button on the applet buttons
+#define RADIOACTIVE_TUNER_TIMEOUT       1000
+#define RADIOACTIVE_TUNER_TIMEOUT_FINE  100
 
-#define RADIO_APPLET_TIMEOUT      1000 // Timeout for holding down the
-                                       // mouse button on the applet buttons
-#define RADIO_TUNER_TIMEOUT       1000
-#define RADIO_TUNER_TIMEOUT_FINE  100
-
-// Stupid error in the stock libgnome/libgnome.h
-#include <libgnome/libgnome.h>
-
-#include <string>
-#include <vector>
-
-typedef std::pair<float, std::string> StationData;
-typedef std::vector<StationData>      SpeedButtonData;
-
-#endif
+#endif /* !RADIOACTIVE_H */
